Управление доступом ко специальным командам
Пред. | Глава 3. Настройка | След.

## Управление доступом ко специальным командам

Большая часть команд jabber-бота, модифицирующих сведения о композициях, или управляющих самим ботом, доступна только администраторам. По умолчанию обычным пользователям доступны команды получения информации и голосования.

Для предоставления публичного доступа к закрытым командам используется параметр public_jabber_commands конфигурационного файла. По умолчанию он не установлен, что эквивалентно такому определению:

Пример 3.1. Настройка доступа к командам jabber-бота

    public_jabber_commands: [admins, bm, dump, download, echo, find,
      help, hitlist, last, news, queue, rocks, shitlist, show,
      speak, status, sucks, tags, upload]

Демократические радиостанции могут автоматически выдавать пользователям доступ к администрированию. Для этого нужно указать количество наиболее активно голосующих пользователей, которым выдаются привилегии, и количество дней, за которые учитываются голоса. По умолчанию функция отключена. Список текущих администраторов можно получить командой admin.

Пример 3.2. Автоматическое присвоение статуса администратора

    promote_voters: 10
    promote_voters_days: 14

В этом примере статус администратора выдаётся 10 пользователям, наиболее активно голосовавшим за последние две недели.

Пред. | Наверх | След.
Настройка сторонних программ | Начало | Глава 4. Программирование эфира